popstar package
===============

Submodules
----------

popstar.ferre module
--------------------

.. automodule:: popstar.ferre
   :members:
   :undoc-members:
   :show-inheritance:

popstar.ssp module
------------------

.. automodule:: popstar.ssp
   :members:
   :undoc-members:
   :show-inheritance:

popstar.utils module
--------------------

.. automodule:: popstar.utils
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: popstar
   :members:
   :undoc-members:
   :show-inheritance:
